@@ -15,6 +15,9 @@ use std::{env, fmt, fs, io, mem};
 #[cfg(not(target_os = "emscripten"))]
 use uuid::Uuid;
 
+#[cfg(feature = "fs_utf8")]
+pub mod utf8;
+
 #[doc(hidden)]
 pub use cap_std::ambient_authority_known_at_compile_time;
 pub use cap_std::{ambient_authority, AmbientAuthority};
